dirent

package
v1.10.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 1, 2021 License: BSD-3-Clause Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	AIO_PRIO_DELTA_MAX                   = 20
	DELAYTIMER_MAX                       = 2147483647
	HOST_NAME_MAX                        = 64
	LOGIN_NAME_MAX                       = 256
	MAXNAMLEN                            = 255
	MAX_CANON                            = 255
	MAX_INPUT                            = 255
	MQ_PRIO_MAX                          = 32768
	NAME_MAX                             = 255
	NGROUPS_MAX                          = 65536
	PATH_MAX                             = 4096
	PIPE_BUF                             = 4096
	PTHREAD_DESTRUCTOR_ITERATIONS        = 4
	PTHREAD_KEYS_MAX                     = 1024
	PTHREAD_STACK_MIN                    = 16384
	RTSIG_MAX                            = 32
	SEM_VALUE_MAX                        = 2147483647
	TTY_NAME_MAX                         = 32
	XATTR_LIST_MAX                       = 65536
	XATTR_NAME_MAX                       = 255
	XATTR_SIZE_MAX                       = 65536
	X_ATFILE_SOURCE                      = 1
	X_BITS_POSIX1_LIM_H                  = 1
	X_BITS_TYPESIZES_H                   = 1
	X_BITS_TYPES_H                       = 1
	X_BSD_SIZE_T_                        = 0
	X_BSD_SIZE_T_DEFINED_                = 0
	X_DEFAULT_SOURCE                     = 1
	X_DIRENT_H                           = 1
	X_DIRENT_HAVE_D_OFF                  = 0
	X_DIRENT_HAVE_D_RECLEN               = 0
	X_DIRENT_HAVE_D_TYPE                 = 0
	X_DIRENT_MATCHES_DIRENT64            = 1
	X_FEATURES_H                         = 1
	X_FILE_OFFSET_BITS                   = 64
	X_GCC_SIZE_T                         = 0
	X_LINUX_LIMITS_H                     = 0
	X_LP64                               = 1
	X_POSIX_AIO_LISTIO_MAX               = 2
	X_POSIX_AIO_MAX                      = 1
	X_POSIX_ARG_MAX                      = 4096
	X_POSIX_CHILD_MAX                    = 25
	X_POSIX_CLOCKRES_MIN                 = 20000000
	X_POSIX_C_SOURCE                     = 200809
	X_POSIX_DELAYTIMER_MAX               = 32
	X_POSIX_HOST_NAME_MAX                = 255
	X_POSIX_LINK_MAX                     = 8
	X_POSIX_LOGIN_NAME_MAX               = 9
	X_POSIX_MAX_CANON                    = 255
	X_POSIX_MAX_INPUT                    = 255
	X_POSIX_MQ_OPEN_MAX                  = 8
	X_POSIX_MQ_PRIO_MAX                  = 32
	X_POSIX_NAME_MAX                     = 14
	X_POSIX_NGROUPS_MAX                  = 8
	X_POSIX_OPEN_MAX                     = 20
	X_POSIX_PATH_MAX                     = 256
	X_POSIX_PIPE_BUF                     = 512
	X_POSIX_RE_DUP_MAX                   = 255
	X_POSIX_RTSIG_MAX                    = 8
	X_POSIX_SEM_NSEMS_MAX                = 256
	X_POSIX_SEM_VALUE_MAX                = 32767
	X_POSIX_SIGQUEUE_MAX                 = 32
	X_POSIX_SOURCE                       = 1
	X_POSIX_SSIZE_MAX                    = 32767
	X_POSIX_STREAM_MAX                   = 8
	X_POSIX_SYMLINK_MAX                  = 255
	X_POSIX_SYMLOOP_MAX                  = 8
	X_POSIX_THREAD_DESTRUCTOR_ITERATIONS = 4
	X_POSIX_THREAD_KEYS_MAX              = 128
	X_POSIX_THREAD_THREADS_MAX           = 64
	X_POSIX_TIMER_MAX                    = 32
	X_POSIX_TTY_NAME_MAX                 = 9
	X_POSIX_TZNAME_MAX                   = 6
	X_SIZET_                             = 0
	X_SIZE_T                             = 0
	X_SIZE_T_                            = 0
	X_SIZE_T_DECLARED                    = 0
	X_SIZE_T_DEFINED                     = 0
	X_SIZE_T_DEFINED_                    = 0
	X_STDC_PREDEF_H                      = 1
	X_SYS_CDEFS_H                        = 1
	X_SYS_SIZE_T_H                       = 0
	X_T_SIZE                             = 0
	X_T_SIZE_                            = 0
	Linux                                = 1
	Unix                                 = 1
)
const (
	DT_UNKNOWN = 0
	DT_FIFO    = 1
	DT_CHR     = 2
	DT_DIR     = 4
	DT_BLK     = 6
	DT_REG     = 8
	DT_LNK     = 10
	DT_SOCK    = 12
	DT_WHT     = 14
)

File types for `d_type'.

Variables

var CAPI = map[string]struct{}{}

Functions

This section is empty.

Types

type Dirent

type Dirent = struct {
	Fd_ino    X__ino64_t
	Fd_off    X__off64_t
	Fd_reclen uint16
	Fd_type   uint8
	Fd_name   [256]int8
	// contains filtered or unexported fields

} /* dirent.h:22:1 */

type Ptrdiff_t

type Ptrdiff_t = int64 /* <builtin>:3:26 */

type Size_t

type Size_t = uint64 /* <builtin>:9:23 */

type Wchar_t

type Wchar_t = int32 /* <builtin>:15:24 */

type X__blkcnt64_t

type X__blkcnt64_t = int64 /* types.h:178:30 */

type X__blkcnt_t

type X__blkcnt_t = int64 /* types.h:177:28 */

Type to count number of disk blocks.

type X__blksize_t

type X__blksize_t = int64 /* types.h:172:29 */

Type to represent block size.

type X__builtin_va_list

type X__builtin_va_list = uintptr /* <builtin>:46:14 */

type X__caddr_t

type X__caddr_t = uintptr /* types.h:201:14 */

type X__clock_t

type X__clock_t = int64 /* types.h:154:27 */ // Type of CPU usage counts.

type X__clockid_t

type X__clockid_t = int32 /* types.h:166:29 */

Clock ID used in clock and timer functions.

type X__daddr_t

type X__daddr_t = int32 /* types.h:162:27 */ // The type of a disk address.

type X__dev_t

type X__dev_t = uint64 /* types.h:143:25 */ // Type of device numbers.

type X__float128

type X__float128 = float64 /* <builtin>:47:21 */

type X__fsblkcnt64_t

type X__fsblkcnt64_t = uint64 /* types.h:182:32 */

type X__fsblkcnt_t

type X__fsblkcnt_t = uint64 /* types.h:181:30 */

Type to count file system blocks.

type X__fsfilcnt64_t

type X__fsfilcnt64_t = uint64 /* types.h:186:32 */

type X__fsfilcnt_t

type X__fsfilcnt_t = uint64 /* types.h:185:30 */

Type to count file system nodes.

type X__fsid_t

type X__fsid_t = struct{ F__val [2]int32 } /* types.h:153:26 */ // Type of file system IDs.

type X__fsword_t

type X__fsword_t = int64 /* types.h:189:28 */

Type of miscellaneous file system fields.

type X__gid_t

type X__gid_t = uint32 /* types.h:145:25 */ // Type of group identifications.

type X__id_t

type X__id_t = uint32 /* types.h:157:24 */ // General type for IDs.

type X__ino64_t

type X__ino64_t = uint64 /* types.h:147:27 */ // Type of file serial numbers (LFS).

type X__ino_t

type X__ino_t = uint64 /* types.h:146:25 */ // Type of file serial numbers.

type X__int8_t

type X__int8_t = int8 /* types.h:36:21 */

Fixed-size types, underlying types depend on word size and compiler.

type X__int16_t

type X__int16_t = int16 /* types.h:38:26 */

type X__int32_t

type X__int32_t = int32 /* types.h:40:20 */

type X__int64_t

type X__int64_t = int64 /* types.h:43:25 */

type X__int128_t added in v1.3.0

type X__int128_t = struct {
	Flo int64
	Fhi int64

} /* <builtin>:21:43 */ // must match modernc.org/mathutil.Int128

type X__int_least8_t

type X__int_least8_t = X__int8_t /* types.h:51:18 */

Smallest types with at least a given width.

type X__int_least16_t

type X__int_least16_t = X__int16_t /* types.h:53:19 */

type X__int_least32_t

type X__int_least32_t = X__int32_t /* types.h:55:19 */

type X__int_least64_t

type X__int_least64_t = X__int64_t /* types.h:57:19 */

type X__intmax_t

type X__intmax_t = int64 /* types.h:71:18 */

Largest integral types.

type X__intptr_t

type X__intptr_t = int64 /* types.h:204:25 */

Duplicates info from stdint.h but this is used in unistd.h.

type X__key_t

type X__key_t = int32 /* types.h:163:25 */ // Type of an IPC key.

type X__loff_t

type X__loff_t = X__off64_t /* types.h:200:19 */ // Type of file sizes and offsets (LFS).

These few don't really vary by system, they always correspond

to one of the other defined types.

type X__mode_t

type X__mode_t = uint32 /* types.h:148:26 */ // Type of file attribute bitmasks.
type X__nlink_t = uint64 /* types.h:149:27 */ // Type of file link counts.

type X__off64_t

type X__off64_t = int64 /* types.h:151:27 */ // Type of file sizes and offsets (LFS).

type X__off_t

type X__off_t = int64 /* types.h:150:25 */ // Type of file sizes and offsets.

type X__pid_t

type X__pid_t = int32 /* types.h:152:25 */ // Type of process identifications.

type X__quad_t

type X__quad_t = int64 /* types.h:62:18 */

quad_t is also 64 bits.

type X__rlim64_t

type X__rlim64_t = uint64 /* types.h:156:28 */ // Type for resource measurement (LFS).

type X__rlim_t

type X__rlim_t = uint64 /* types.h:155:26 */ // Type for resource measurement.

type X__sig_atomic_t

type X__sig_atomic_t = int32 /* types.h:212:13 */

C99: An integer type that can be accessed as an atomic entity,

even in the presence of asynchronous interrupts.
It is not currently necessary for this to be machine-specific.

type X__socklen_t

type X__socklen_t = uint32 /* types.h:207:23 */

Duplicate info from sys/socket.h.

type X__ssize_t

type X__ssize_t = int64 /* types.h:191:27 */ // Type of a byte count, or error.

type X__suseconds_t

type X__suseconds_t = int64 /* types.h:160:31 */ // Signed count of microseconds.

type X__syscall_slong_t

type X__syscall_slong_t = int64 /* types.h:194:33 */

Signed long type used in system calls.

type X__syscall_ulong_t

type X__syscall_ulong_t = uint64 /* types.h:196:33 */

Unsigned long type used in system calls.

type X__time_t

type X__time_t = int64 /* types.h:158:26 */ // Seconds since the Epoch.

type X__timer_t

type X__timer_t = uintptr /* types.h:169:12 */

Timer ID returned by `timer_create'.

type X__u_char

type X__u_char = uint8 /* types.h:30:23 */

Convenience types.

type X__u_int

type X__u_int = uint32 /* types.h:32:22 */

type X__u_long

type X__u_long = uint64 /* types.h:33:27 */

type X__u_quad_t

type X__u_quad_t = uint64 /* types.h:63:27 */

type X__u_short

type X__u_short = uint16 /* types.h:31:28 */

type X__uid_t

type X__uid_t = uint32 /* types.h:144:25 */ // Type of user identifications.

type X__uint8_t

type X__uint8_t = uint8 /* types.h:37:23 */

type X__uint16_t

type X__uint16_t = uint16 /* types.h:39:28 */

type X__uint32_t

type X__uint32_t = uint32 /* types.h:41:22 */

type X__uint64_t

type X__uint64_t = uint64 /* types.h:44:27 */

type X__uint128_t added in v1.3.0

type X__uint128_t = struct {
	Flo uint64
	Fhi uint64

} /* <builtin>:22:44 */ // must match modernc.org/mathutil.Int128

type X__uint_least8_t

type X__uint_least8_t = X__uint8_t /* types.h:52:19 */

type X__uint_least16_t

type X__uint_least16_t = X__uint16_t /* types.h:54:20 */

type X__uint_least32_t

type X__uint_least32_t = X__uint32_t /* types.h:56:20 */

type X__uint_least64_t

type X__uint_least64_t = X__uint64_t /* types.h:58:20 */

type X__uintmax_t

type X__uintmax_t = uint64 /* types.h:72:27 */

type X__useconds_t

type X__useconds_t = uint32 /* types.h:159:30 */ // Count of microseconds.

Jump to